summaryrefslogtreecommitdiffstats
path: root/interfaces/ktexteditor/selectiondcopinterface.h
diff options
context:
space:
mode:
Diffstat (limited to 'interfaces/ktexteditor/selectiondcopinterface.h')
-rw-r--r--interfaces/ktexteditor/selectiondcopinterface.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/interfaces/ktexteditor/selectiondcopinterface.h b/interfaces/ktexteditor/selectiondcopinterface.h
index 87efc1918..aa2973540 100644
--- a/interfaces/ktexteditor/selectiondcopinterface.h
+++ b/interfaces/ktexteditor/selectiondcopinterface.h
@@ -3,8 +3,8 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
namespace KTextEditor
{
@@ -49,9 +49,9 @@ namespace KTextEditor
bool hasSelection ();
/**
* @return a QString for the selected text
*/
- QString selection ();
+ TQString selection ();
/**
* removes the selected Text
@@ -49,9 +49,9 @@ namespace KTextEditor
bool hasSelection ();
/**
- * @return a QString for the selected text
+ * @return a TQString for the selected text
*/